@@ -6,7 +6,7 @@
 use v5.26;
 use Object::Pad 0.38; # Object::Pad::MOP::Class->for_caller
 
-package Test::Device::Chip::Adapter 0.17;
+package Test::Device::Chip::Adapter 0.18;
 class Test::Device::Chip::Adapter
    implements Device::Chip::Adapter;
 
@@ -63,6 +63,7 @@ has $_protocol;
 
 has $_controller;
 has $_obj;
+has $_txn_helper;
 
 BUILD
 {
@@ -186,14 +187,24 @@ BEGIN {
       );
    }
 
+   class Test::Device::Chip::Adapter::_TxnHelper {
+      has $_adapter;
+      BUILD { ( $_adapter ) = @_; }
+
+      async method write { await $_adapter->write( @_ ) }
+      async method read  { return await $_adapter->read( @_ ) }
+   }
+
    async method txn ( $code )
    {
       $_protocol eq "I2C" or
          croak "Method ->txn not allowed in $_protocol protocol";
 
+      $_txn_helper //= Test::Device::Chip::Adapter::_TxnHelper->new( $self );
+
       $_obj->txn_start;
 
-      my $result = await $code->();
+      my $result = await $code->( $_txn_helper );
 
       $_obj->txn_stop;
 
